@@ -10,20 +10,20 @@
 
 #if !defined Q_OS_ANDROID
 #include <QDBusInterface>
-#include <QtSystemInfo/qinputinfo.h>
-#endif
-
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <QTouchDevice>
+#define QT5_BASED
+#include <QtSystemInfo/qinputinfo.h>
 #else
+#define QT6_BASED
 #include <QInputDevice>
 #endif
+#endif
 
 using namespace MauiMan;
 
 #if !defined Q_OS_ANDROID
-static
-QString typeToString(QInputDevice::InputTypeFlags type)
+#ifdef QT5_BASE
+static QString typeToString(QInputDevice::InputTypeFlags type)
 {
     qDebug() << type;
     QStringList typeString;
@@ -42,23 +42,41 @@ QString typeToString(QInputDevice::InputTypeFlags type)
 
     if (typeString.isEmpty())
         typeString << QStringLiteral("Unknown");
-    return typeString.join((", "));
+    return typeString.join((QStringLiteral(", ")));
 }
+#elif defined QT6_BASE
+static QString typeToString(QInputDevice::DeviceTypes type)
+{
+    qDebug() << type;
+    QStringList typeString;
+    if (type.testFlag(QInputDevice::DeviceType::Mouse))
+        typeString << QStringLiteral("Mouse");
+    if (type.testFlag(QInputDevice::DeviceType::TouchPad))
+        typeString << QStringLiteral("TouchPad");
+    if (type.testFlag(QInputDevice::DeviceType::TouchScreen))
+        typeString << QStringLiteral("TouchScreen");
+    if (type.testFlag(QInputDevice::DeviceType::Keyboard))
+        typeString << QStringLiteral("Keyboard");
+    if (typeString.isEmpty())
+        typeString << QStringLiteral("Unknown");
+    return typeString.join((QStringLiteral(", ")));
+}
+#endif
 #endif
 
 void FormFactorManager::sync(const QString &key, const QVariant &value)
 {
-#if !defined Q_OS_ANDROID
+    #if !defined Q_OS_ANDROID
     if (m_interface && m_interface->isValid())
     {
         m_interface->call(key, value);
     }
-#endif
+    #endif
 }
 
 void FormFactorManager::setConnections()
 {
-#if !defined Q_OS_ANDROID
+    #if !defined Q_OS_ANDROID
     if(m_interface)
     {
         m_interface->disconnect();
@@ -75,31 +93,31 @@ void FormFactorManager::setConnections()
     {
         connect(m_interface, SIGNAL(preferredModeChanged(uint)), this, SLOT(onPreferredModeChanged(uint)));
     }
-#endif
+    #endif
 }
 
 void FormFactorManager::loadSettings()
 {
     m_settings->beginModule(QStringLiteral("FormFactor"));
 
-#if !defined Q_OS_ANDROID
+    #if !defined Q_OS_ANDROID
     if(m_interface && m_interface->isValid())
     {
         m_preferredMode = m_interface->property("preferredMode").toUInt();
         return;
     }
-#endif
+    #endif
 
     m_preferredMode = m_settings->load(QStringLiteral("PreferredMode"), m_preferredMode).toUInt();
 }
 
 FormFactorManager::FormFactorManager(QObject *parent) : MauiMan::FormFactorInfo(parent)
-  ,m_settings(new MauiMan::SettingsStore(this))
-  ,m_info(new MauiMan::FormFactorInfo(this))
+,m_settings(new MauiMan::SettingsStore(this))
+,m_info(new MauiMan::FormFactorInfo(this))
 {
     qDebug( " INIT FORMFACTOR MANAGER");
 
-#if !defined Q_OS_ANDROID
+    #if !defined Q_OS_ANDROID
     auto server = new MauiManUtils(this);
     if(server->serverRunning())
     {
@@ -113,7 +131,7 @@ FormFactorManager::FormFactorManager(QObject *parent) : MauiMan::FormFactorInfo(
             this->setConnections();
         }
     });
-#endif
+    #endif
     m_preferredMode = defaultMode();
 
     loadSettings();
@@ -234,9 +252,22 @@ void FormFactorInfo::findBestMode()
     Q_EMIT bestModeChanged(m_bestMode);
 }
 
+QRect FormFactorInfo::screenSize()
+{
+    QScreen *screen = qApp->primaryScreen();
+    return screen->geometry();
+}
+
+Qt::ScreenOrientation FormFactorInfo::screenOrientation()
+{
+    QScreen *screen = qApp->primaryScreen();
+    return screen->orientation();
+}
+
+#ifdef QT5_BASE
 void FormFactorInfo::checkInputs(const QInputInfoManager *inputManager)
 {
-#if !defined Q_OS_ANDROID
+    #if !defined Q_OS_ANDROID
 
     //        qDebug() <<"Found"<<  inputDeviceManager->deviceMap().count() << "input devices";
     //        QMapIterator<QString, QInputDevice*> i(inputDeviceManager->deviceMap());
@@ -273,27 +304,40 @@ void FormFactorInfo::checkInputs(const QInputInfoManager *inputManager)
     qDebug() << "Number of mice:" << mouseCount;
     qDebug() << "Number of touchscreens:" << touchCount;
     qDebug() << "Number of touchpads:" << trackpadCount;
+    #endif
+}
+#elif defined QT6_BASE
+void FormFactorInfo::checkInputs(const QList<const QInputDevice *> &devices)
+{
+    auto hasType = [devices](QInputDevice::DeviceType type) -> bool
+    {
+        auto res= std::find_if(devices.constBegin(), devices.constEnd(), [type](const QInputDevice *device)
+        {
+            return device->type() == type;
+        });
+
+        return res != std::end(devices);
+    };
+
+    m_hasKeyboard = hasType(QInputDevice::DeviceType::Keyboard);
+    m_hasMouse =  hasType(QInputDevice::DeviceType::Mouse);
+    m_hasTouchscreen =  hasType(QInputDevice::DeviceType::TouchScreen);
+    m_hasTouchpad =  hasType(QInputDevice::DeviceType::TouchPad);
+
+    Q_EMIT hasKeyboardChanged(m_hasKeyboard);
+    Q_EMIT hasMouseChanged(m_hasMouse);
+    Q_EMIT hasTouchscreenChanged(m_hasTouchscreen);
+    Q_EMIT hasTouchpadChanged(m_hasTouchpad);
+}
 #endif
-}
-
-QRect FormFactorInfo::screenSize()
-{
-    QScreen *screen = qApp->primaryScreen();
-    return screen->geometry();
-}
-
-Qt::ScreenOrientation FormFactorInfo::screenOrientation()
-{
-    QScreen *screen = qApp->primaryScreen();
-    return screen->orientation();
-}
-
 
 FormFactorInfo::FormFactorInfo(QObject *parent) : QObject(parent)
 {
     qDebug( " INIT FORMFACTOR INFO");
 
-#if !defined Q_OS_ANDROID
+    #if !defined Q_OS_ANDROID
+
+    #ifdef QT5_BASED
     auto inputDeviceManager = new QInputInfoManager(this);
     connect(inputDeviceManager, &QInputInfoManager::ready,[ inputDeviceManager]()
     {
@@ -317,33 +361,10 @@ FormFactorInfo::FormFactorInfo(QObject *parent) : QObject(parent)
         checkInputs(inputDeviceManager);
         findBestMode();
     });
-
-
-    //** Ask for screen sizes and dimension etc to Cask via CaskServer**//
-
-    //    auto dummyApp = new QGuiApplication(0, []);
-    //    QScreen *screen = QGuiApplication::primaryScreen();
-    //    connect(screen, &QScreen::geometryChanged, [this](QRect rect)
-    //    {
-    //        m_screenSize = rect;
-    //        Q_EMIT screenSizeChanged(m_screenSize);
-
-    //        findBestMode();
-    //    });
-
-    //    connect(screen, &QScreen::primaryOrientationChanged, [this](Qt::ScreenOrientation orientation)
-    //    {
-    //        m_screenOrientation = orientation;
-    //        Q_EMIT screenOrientationChanged(m_screenOrientation);
-
-    //        findBestMode();
-    //    });
-
-    // m_screenSize = screen->geometry();
-    //    m_screenOrientation = screen->primaryOrientation();
-
-
+    #elif defined QT6_BASE
+    checkInputs(QInputDevice::devices());
+    #endif
     findBestMode();
-#endif
+    #endif
 
 }
